package factura40;

import javax.xml.bind.annotation.XmlRegistry;
import factura40.*;

@XmlRegistry
public class ObjectFactory {

    public ObjectFactory() {
    }

    public Comprobante40 createComprobante() {
        return new Comprobante40();
    }

    public Comprobante40.Impuestos createComprobanteImpuestos() {
        return new Comprobante40.Impuestos();
    }

    public Comprobante40.Impuestos.Traslados createComprobanteImpuestosTraslados() {
        return new Comprobante40.Impuestos.Traslados();
    }

    public Comprobante40.Impuestos.Retenciones createComprobanteImpuestosRetenciones() {
        return new Comprobante40.Impuestos.Retenciones();
    }

    public Conceptos createComprobanteConceptos() {
        return new Conceptos();
    }

    public Conceptos.Concepto createComprobanteConceptosConcepto() {
        return new Conceptos.Concepto();
    }

    public Conceptos.Concepto.Parte createComprobanteConceptosConceptoParte() {
        return new Conceptos.Concepto.Parte();
    }

    public Conceptos.Concepto.Impuestos createComprobanteConceptosConceptoImpuestos() {
        return new Conceptos.Concepto.Impuestos();
    }

    public Conceptos.Concepto.Impuestos.Retenciones createComprobanteConceptosConceptoImpuestosRetenciones() {
        return new Conceptos.Concepto.Impuestos.Retenciones();
    }

    public Conceptos.Concepto.Impuestos.Traslados createComprobanteConceptosConceptoImpuestosTraslados() {
        return new Conceptos.Concepto.Impuestos.Traslados();
    }

    public Comprobante40.CfdiRelacionados createComprobanteCfdiRelacionados() {
        return new Comprobante40.CfdiRelacionados();
    }

    public Comprobante40.InformacionGlobal createComprobanteInformacionGlobal() {
        return new Comprobante40.InformacionGlobal();
    }

    public Comprobante40.Emisor createComprobanteEmisor() {
        return new Comprobante40.Emisor();
    }

    public Comprobante40.Receptor createComprobanteReceptor() {
        return new Comprobante40.Receptor();
    }

    public Comprobante40.Complemento createComprobanteComplemento() {
        return new Comprobante40.Complemento();
    }

    public Comprobante40.Addenda createComprobanteAddenda() {
        return new Comprobante40.Addenda();
    }

    public Comprobante40.Impuestos.Traslados.Traslado createComprobanteImpuestosTrasladosTraslado() {
        return new Comprobante40.Impuestos.Traslados.Traslado();
    }

    public Comprobante40.Impuestos.Retenciones.Retencion createComprobanteImpuestosRetencionesRetencion() {
        return new Comprobante40.Impuestos.Retenciones.Retencion();
    }

    public Conceptos.Concepto.ACuentaTerceros createComprobanteConceptosConceptoACuentaTerceros() {
        return new Conceptos.Concepto.ACuentaTerceros();
    }

    public Conceptos.Concepto.InformacionAduanera createComprobanteConceptosConceptoInformacionAduanera() {
        return new Conceptos.Concepto.InformacionAduanera();
    }

    public Conceptos.Concepto.CuentaPredial createComprobanteConceptosConceptoCuentaPredial() {
        return new Conceptos.Concepto.CuentaPredial();
    }

    public Conceptos.Concepto.ComplementoConcepto createComprobanteConceptosConceptoComplementoConcepto() {
        return new Conceptos.Concepto.ComplementoConcepto();
    }

    public Conceptos.Concepto.Parte.InformacionAduanera createComprobanteConceptosConceptoParteInformacionAduanera() {
        return new Conceptos.Concepto.Parte.InformacionAduanera();
    }

    public Conceptos.Concepto.Impuestos.Retenciones.Retencion createComprobanteConceptosConceptoImpuestosRetencionesRetencion() {
        return new Conceptos.Concepto.Impuestos.Retenciones.Retencion();
    }

    public Conceptos.Concepto.Impuestos.Traslados.Traslado createComprobanteConceptosConceptoImpuestosTrasladosTraslado() {
        return new Conceptos.Concepto.Impuestos.Traslados.Traslado();
    }

    public Comprobante40.CfdiRelacionados.CfdiRelacionado createComprobanteCfdiRelacionadosCfdiRelacionado() {
        return new Comprobante40.CfdiRelacionados.CfdiRelacionado();
    }

}
